@@ -17,6 +17,7 @@ import qualified Data.Foldable as F
 import qualified Data.String as S
 import Control.Category
 import Data.Char (Char)
+import GHC.Exts (IsList(..))
 
 instance FoldableLL (DList a) a where
   foldl = F.foldl
@@ -36,13 +37,13 @@ instance ListLike (DList a) a where
   tail = D.tail
   rigidMap = D.map
   null = null . D.toList
-  toList = D.toList
-  fromList = D.fromList
+  --toList = D.toList
+  --fromList = D.fromList
   replicate = D.replicate
 
 instance StringLike (DList Char) where
   toString = D.toList
-  fromString = D.fromList
+  -- fromString = D.fromList
   lines = map D.fromList . S.lines . D.toList
   words = map D.fromList . S.words . D.toList
   unlines = D.fromList . S.unlines . map D.toList
