@@ -1,6 +1,7 @@
 {-# LANGUAGE CPP
             ,MultiParamTypeClasses
             ,FlexibleInstances
+            ,TypeFamilies
             ,TypeSynonymInstances #-}
 {-# OPTIONS -fno-warn-orphans #-}
 
@@ -63,10 +64,12 @@ import qualified Data.Array.IArray as A
 import           Data.Array.IArray((!), (//), Ix(..))
 import qualified Data.ByteString.Lazy as BSL
 import qualified Data.ByteString.Lazy.Char8 as BSLC
+import           Data.String (IsString(fromString))
 --import           Data.String.UTF8 (UTF8)
 --import qualified Data.String.UTF8 as UTF8
 import qualified System.IO as IO
 import           Data.Word
+import           GHC.Exts (IsList(..))
 
 --------------------------------------------------
 -- []
@@ -111,7 +114,7 @@ illegalBufferSize handle fn sz =
 
 instance StringLike String where
     toString = id
-    fromString = id
+    --fromString = id
 
 instance InfiniteListLike [a] a where
     iterate = L.iterate
@@ -129,6 +132,11 @@ instance FoldableLL BS.ByteString Word8 where
     foldr' = BS.foldr'
     foldr1 = BS.foldr1
 
+instance IsList BS.ByteString where
+    type Item BS.ByteString = Word8
+    toList = BS.unpack
+    fromList = BS.pack
+
 instance ListLike BS.ByteString Word8 where
     empty = BS.empty
     singleton = BS.singleton
@@ -188,8 +196,6 @@ instance ListLike BS.ByteString Word8 where
     --intersect = BS.intersect
     sort = BS.sort
     --insert = BS.insert
-    toList = BS.unpack
-    fromList = BS.pack
     --fromListLike = fromList . toList
     --nubBy = BS.nubBy
     --deleteBy = BS.deleteBy
@@ -231,7 +237,7 @@ instance ListLikeIO BS.ByteString Word8 where
 #if 0
 instance StringLike BS.ByteString where
     toString = BSU.toString
-    fromString = BSU.fromString
+    --fromString = BSU.fromString
 #endif
 
 --------------------------------------------------
@@ -249,6 +255,11 @@ mi64toi :: Maybe Int64 -> Maybe Int
 mi64toi Nothing = Nothing
 mi64toi (Just x) = Just (fromIntegral x)
 
+instance IsList BSL.ByteString where
+    type Item BSL.ByteString = Word8
+    toList = BSL.unpack
+    fromList = BSL.pack
+
 instance ListLike BSL.ByteString Word8 where
     empty = BSL.empty
     singleton = BSL.singleton
@@ -309,8 +320,6 @@ instance ListLike BSL.ByteString Word8 where
     --intersect = BSL.intersect
     --sort = BSL.sort
     --insert = BSL.insert
-    toList = BSL.unpack
-    fromList = BSL.pack
     --fromListLike = fromList . toList
     --nubBy = BSL.nubBy
     --deleteBy = BSL.deleteBy
@@ -349,7 +358,7 @@ instance ListLikeIO BSL.ByteString Word8 where
 #if 0
 instance StringLike BSL.ByteString where
     toString = BSLU.toString
-    fromString = BSLU.fromString
+    --fromString = BSLU.fromString
 #endif
 
 --------------------------------------------------
@@ -387,6 +396,11 @@ instance (Integral i, Ix i) => Monoid (A.Array i e) where
               newbhigh = bhigh + newlen
               (blow, bhigh) = A.bounds l1
 
+instance (Integral i, Ix i) => IsList (A.Array i e) where
+    type Item (A.Array i e) = e
+    toList = A.elems
+    fromList l = A.listArray (0, genericLength l - 1) l
+
 instance (Integral i, Ix i) => ListLike (A.Array i e) e where
     empty = mempty
     singleton i = A.listArray (0, 0) [i]
@@ -453,8 +467,6 @@ instance (Integral i, Ix i) => ListLike (A.Array i e) e where
     -- intersect
     sort l = A.listArray (A.bounds l) (L.sort (A.elems l))
     -- insert
-    toList = A.elems
-    fromList l = A.listArray (0, genericLength l - 1) l
     -- fromListLike
     nubBy f = fromList . L.nubBy f . toList
     -- deleteBy
@@ -480,9 +492,11 @@ instance (Integral i, Ix i) => ListLike (A.Array i e) e where
                                            (L.genericReplicate count i)
 
 
+instance (Integral i, Ix i) => IsString (A.Array i Char) where
+    fromString = fromList
+
 instance (Integral i, Ix i) => StringLike (A.Array i Char) where
     toString = toList
-    fromString = fromList
     -- lines
     -- words
 
@@ -521,9 +535,14 @@ instance ListLikeIO (S.Seq Char) Char where
     -- writeFile
     -- appendFile
 
+#if !MIN_VERSION_containers(0,5,7)
+instance IsString (S.Seq Char) where
+  fromString = S.fromList
+#endif
+
 instance StringLike (S.Seq Char) where
     toString = toList
-    fromString = fromList
+    --fromString = fromList
 
 instance FoldableLL (S.Seq a) a where
     foldl = F.foldl
@@ -589,8 +608,6 @@ instance ListLike (S.Seq a) a where
     --intersect =
     sort = S.sort
     --insert = S.insert
-    toList = F.toList
-    fromList = S.fromList
     --fromListLike = fromList . toList
     --nubBy =
     --deleteBy =
