@@ -1,5 +1,6 @@
 {-# LANGUAGE CPP
             ,MultiParamTypeClasses
+            ,TypeFamilies
             ,FlexibleInstances #-}
 {-# OPTIONS -fno-warn-orphans #-}
 
@@ -18,11 +19,18 @@ import           Data.ListLike.IO
 import           Data.ListLike.String as LL
 import           Data.ListLike.Text.TextLazy ()
 --import           Data.String (IsString(fromString))
+import           GHC.Exts (IsList(..))
 
 instance FoldableLL Builder.Builder Char where
     foldl f r0 = LL.foldl f r0 . Builder.toLazyText
     foldr f r0 = LL.foldr f r0 . Builder.toLazyText
 
+instance IsList Builder.Builder where
+    type Item Builder.Builder = Char
+    -- Can we do better?
+    toList = LL.toList'
+    fromList = LL.fromList'
+
 instance ListLike Builder.Builder Char where
     singleton = Builder.singleton
     uncons b = case LL.uncons (Builder.toLazyText b) of
@@ -39,7 +47,8 @@ instance ListLikeIO Builder.Builder Char where
 
 instance StringLike Builder.Builder where
     toString = toString . Builder.toLazyText
-    fromString = Builder.fromLazyText . LL.fromString
+    fromText = Builder.fromText
+    fromLazyText = Builder.fromLazyText
 
 instance NFData Builder.Builder where
     rnf = rnf . Builder.toLazyText
