@@ -24,16 +24,17 @@ import qualified Data.ByteString.Char8 as BSC
 import qualified Data.ByteString.Lazy as BSL
 import qualified Data.ByteString.Lazy.Char8 as BSLC
 --import Control.DeepSeq (NFData(rnf))
-import Data.ListLike.Base
+import Data.ListLike.Base as LL
 import Data.ListLike.FoldableLL
 import Data.ListLike.IO
 import Data.ListLike.String (StringLike(..))
 import Data.Maybe (fromMaybe)
 import Data.Monoid (Monoid(..))
 import Data.Semigroup (Semigroup(..))
---import Data.String (IsString(fromString))
+import Data.String (IsString(fromString))
 import Data.String.UTF8 (UTF8{-, UTF8Bytes-})
 import qualified Data.String.UTF8 as UTF8
+import GHC.Exts (IsList(..))
 --import GHC.Generics
 
 #if 0
@@ -49,6 +50,11 @@ instance FoldableLL (UTF8 BS.ByteString) Char where
     -- foldr' = UTF8.foldr'
     -- foldr1 = UTF8.foldr1
 
+instance IsList (UTF8 BS.ByteString) where
+    type Item (UTF8 BS.ByteString) = Char
+    toList = UTF8.toString
+    fromList = LL.fromList' -- LL.map id
+
 instance ListLike (UTF8 BS.ByteString) Char where
     empty = mempty
     singleton c = UTF8.fromString [c]
@@ -108,7 +114,7 @@ instance ListLike (UTF8 BS.ByteString) Char where
     -- --intersect = UTF8.intersect
     -- sort = UTF8.sort
     -- --insert = UTF8.insert
-    toList = UTF8.toString
+    --toList = UTF8.toString
     -- fromList = UTF8.pack
     -- fromListLike = fromList . toList
     -- --nubBy = UTF8.nubBy
@@ -141,9 +147,11 @@ instance ListLikeIO (UTF8 BS.ByteString) Char where
     -- writeFile = BS.writeFile
     -- appendFile = BS.appendFile
 
+instance IsString (UTF8 BS.ByteString) where
+    fromString = UTF8.fromString
+
 instance StringLike (UTF8 BS.ByteString) where
     toString = UTF8.toString
-    fromString = UTF8.fromString
 
 instance Semigroup (UTF8 BS.ByteString) where
   (<>) = mappend
@@ -163,6 +171,11 @@ instance FoldableLL (UTF8 BSL.ByteString) Char where
     -- foldr' = UTF8.foldr'
     -- foldr1 = UTF8.foldr1
 
+instance IsList (UTF8 BSL.ByteString) where
+    type Item (UTF8 BSL.ByteString) = Char
+    toList = UTF8.toString
+    fromList = LL.fromList' -- LL.map id
+
 instance ListLike (UTF8 BSL.ByteString) Char where
     empty = mempty
     singleton c = UTF8.fromString [c]
@@ -222,7 +235,7 @@ instance ListLike (UTF8 BSL.ByteString) Char where
     -- --intersect = UTF8.intersect
     -- sort = UTF8.sort
     -- --insert = UTF8.insert
-    toList = UTF8.toString
+    -- toList = UTF8.toString
     -- fromList = UTF8.pack
     -- fromListLike = fromList . toList
     -- --nubBy = UTF8.nubBy
@@ -258,9 +271,11 @@ instance ListLikeIO (UTF8 BSL.ByteString) Char where
 instance Semigroup (UTF8 BSL.ByteString) where
   (<>) = mappend
 
+instance IsString (UTF8 BSL.ByteString) where
+    fromString = UTF8.fromString
+
 instance StringLike (UTF8 BSL.ByteString) where
     toString = UTF8.toString
-    fromString = UTF8.fromString
 
 instance Monoid (UTF8 BSL.ByteString) where
     mempty = UTF8.fromString []
