@@ -1,4 +1,5 @@
 {-# LANGUAGE MultiParamTypeClasses
+            ,TypeFamilies
             ,FlexibleInstances #-}
 {-# OPTIONS -fno-warn-orphans #-}
 
@@ -13,9 +14,11 @@ import           Data.Vector.Storable ((!))
 import           Data.ListLike.Base
 import           Data.ListLike.FoldableLL
 import           Data.ListLike.String
+import           Data.String (IsString(fromString))
 
 import           Data.Monoid
 import           Foreign.Storable (Storable)
+import           GHC.Exts (IsList(..))
 
 
 instance Storable a => FoldableLL (V.Vector a) a where
@@ -65,8 +68,8 @@ instance Storable a => ListLike (V.Vector a) a where
     filter = V.filter
     index = (!)
     findIndex = V.findIndex
-    toList = V.toList
-    fromList = V.fromList
+    --toList = V.toList
+    --fromList = V.fromList
     --fromListLike = fromList . toList
     --groupBy f =
     genericLength = fromInteger . fromIntegral . V.length
@@ -78,9 +81,11 @@ instance Storable a => ListLike (V.Vector a) a where
     sequence  = liftM fromList . P.sequence  . toList
     mapM func = liftM fromList . P.mapM func . toList
 
+instance IsString (V.Vector Char) where
+    fromString = fromList
+
 instance StringLike (V.Vector Char) where
     toString = toList
-    fromString = fromList
     --words =
     --lines =
     unwords = let sp = V.singleton ' ' in V.concat . intersperse sp . toList
